@@ -1,6 +1,8 @@
 import argparse
 import json
 import logging
+import traceback
+import sys
 from robocorp_dialog import dialog
 
 LOGGER = logging.getLogger(__name__)
@@ -43,8 +45,9 @@ def main() -> None:
             on_top=args.on_top,
             debug=args.debug,
         )
-    except Exception as exc:  # pylint: disable=broad-except
-        error(str(exc))
+    except Exception:  # pylint: disable=broad-except
+        error(traceback.format_exc())
+        sys.exit(1)
 
 
 if __name__ == "__main__":
